<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="layout_content p-3">
  <div class="success_msg"><?php echo $this->translate('Your message has been sent successfully.') ?>
</div>