
/*VIEW MESSAGES*/
.messages_list_header{
  border-bottom-width:0.0625rem;
  display:flex;
  flex-wrap:wrap;
  padding-bottom:var(--theme-item-spacing);
  margin-bottom:0.9375rem;
}
.messages_list_header_left{
  flex:1;
}
.messages_list_header_search{
  width:18.75rem;
}
.messages_list_header_search input{
  width:100%;
}
.messages_list > ul > li{
  border-bottom-width:0.0625rem;
  clear:both;
  overflow:hidden;
  padding:var(--theme-item-spacing);
  margin:var(--theme-item-spacing) 0;
}
.messages_list > ul > li.messages_list_new{
  border-radius:var(--theme-item-radius);
  background-color:var(--theme-list-background-color-alt);
  border-bottom-width:0;
}
.messages_list .messages_list_checkbox{
  float:left;
  overflow:hidden;
}
[dir="rtl"] .messages_list .messages_list_checkbox{
  float:right;
}
.messages_list .messages_list_photo{
  float:left;
  overflow:hidden;
  padding-left:0.3125rem;
}
[dir="rtl"] .messages_list .messages_list_photo{
  float:right;
  padding-left:0;
  padding-right:0.3125rem;
}
.messages_list .messages_list_photo .bg_item_photo{
  height:3rem;
  width:3rem;
}
.messages_list .messages_list_from{
  float:left;
  overflow:hidden;
  padding-left:0.625rem;
  width:10.625rem;
  word-wrap:break-word;
}
[dir="rtl"] .messages_list .messages_list_from{
  float:right;
  padding-left:0;
  padding-right:0.625rem;
}
.messages_list .messages_list_from > .messages_list_from_name{
	font-weight:var(--theme-font-weight-bold);
}
.messages_list .messages_list_from > .messages_list_from_name a{
  color:var(--theme-font-color);
}
.messages_list .messages_list_info_title, 
.messages_list .messages_list_from_name{
  margin-bottom:0;
}
.messages_list .messages_list_info_title a, 
.messages_list .messages_list_from_name a{
	font-weight:var(--theme-font-weight-bold);
  color:var(--theme-font-color);
}
.messages_list .messages_list_from > .messages_list_from_name a:hover,
.messages_list .messages_list_info_title a:hover, 
.messages_list .messages_list_from_name a:hover{
  color:var(--theme-link-color-hover);
}
.messages_list .messages_list_from > .messages_list_from_date{
  font-size:var(--theme-font-size-small);
  color:var(--theme-font-color-light);
  text-transform:lowercase;
  margin-top:0.3125rem;
}
.messages_list .messages_list_info{
  overflow:hidden;
  padding-left:0.9375rem;
}
[dir="rtl"] .messages_list .messages_list_info{
  padding-left:0;
  padding-right:0.9375rem;
}
.messages_list .messages_list_info > .messages_list_info_body{
  font-size:var(--theme-font-size-small);
  margin-top:0.3125rem;
  padding-left:0.0625rem;
}
[dir="rtl"] .messages_list .messages_list_info > .messages_list_info_body{
  padding-right:0.0625rem;
}
@media (max-width:767px) {
  .messages_list_header{
    flex-direction:column;
  }
  .messages_list_header_search{
    width:100%;
  }
}
@media only screen and (max-width:540px){
  .messages_list .messages_list_photo .bg_item_photo{
    height:1.875rem;
    width:1.875rem;
  }
  .messages_list .messages_list_from{
    width:inherit;
  }
  .messages_list .messages_list_from > p{
    display:inline-block;
  }
  .messages_list .messages_list_from > p.messages_list_from_date:before{
    content:"-";
    margin:0 0.3125rem;
  }
  ul.message_view .message_attachment_info{
    display:block;
    overflow:visible;
  }
  .messages_list .messages_list_info{
    clear:both;
    padding-top:0.625rem;
  }
}
/*VIEW MESSAGE*/
.message_view_header{
  display:flex;
  justify-content:space-between;
}
.message_view_header a{
  color:var(--theme-font-color);
  font-weight:var(--theme-font-weight-bold);
}
.message_view_header a:hover{
  color:var(--theme-link-color-hover);
  text-decoration:none;
}
.message_view_between{
  margin-top:0.25rem;
  margin-bottom:0.625rem;
}
.message_view_actions{
  overflow:hidden;
}
ul.message_view > li{
  clear:both;
  overflow:hidden;
  border-top-width:0.0625rem;
  padding:var(--theme-item-spacing) 0;
}
ul.message_view .message_view_leftwrapper{
  float:left;
}
[dir="rtl"] ul.message_view .message_view_leftwrapper{
  float:right;
}
ul.message_view .message_view_photo{
  float:left;
  overflow:hidden;
  width:3.75rem;
}
[dir="rtl"] ul.message_view .message_view_photo{
  float:right;
}
ul.message_view .message_view_from{
  width:9.375rem;
  float:left;
  overflow:hidden;
  padding-right:0.9375rem;
  font-weight:bold;
}
[dir="rtl"] ul.message_view .message_view_from{
  float:right;
  padding-right:0rem;
  padding-left:0.9375rem;
}
ul.message_view .message_view_from a{
  color:var(--theme-font-color);
  font-weight:var(--theme-font-weight-bold);
}
ul.message_view .message_view_from a:hover{
  color:var(--theme-link-color-hover);
  text-decoration:none;
}
ul.message_view .message_view_from p{
  margin:0;
}
ul.message_view .message_view_from .small{
  font-weight:normal;
}
ul.message_view .message_view_info
{
  overflow:hidden;
}
ul.message_view .message_view_reply{
  clear:both;
  overflow:hidden;
  padding-top:0.3125rem;
}
ul.message_view .message_view_info .buttons
{
  margin-top:0.625rem;
}
ul.message_view .message_view_info textarea{
  max-width:100%;
  min-width:100%;
  width:100%;
  height:6.25rem;
}
ul.message_view .message_attachment{
  display:flex;
  flex-wrap:wrap;
  gap:0.625rem;
  margin-top:0.625rem;
  width:100%;
}
ul.message_view .message_attachment_photo{
  width:6.25rem;
}
ul.message_view .message_attachment_photo img{
  width:100%;
  max-width:100%;
  max-height:inherit;
}
ul.message_view .message_attachment .video_object {
  width:25rem;
  max-width:100%;
}
ul.message_view .message_attachment_info{
  flex:1;
}
ul.message_view .message_attachment_title{
  font-size:var(--theme-font-size-small);
  font-weight:bold;
  margin-bottom:0.125rem;
}
ul.message_view .message_attachment_title a{
  color:var(--theme-font-color);
  font-family:Georgia, serif;
  font-size:1.0625rem;
  font-weight:normal;
}
ul.message_view .message_attachment_desc{
  font-size:var(--theme-font-size-small);
  color:var(--theme-font-color-light);
  display:-webkit-box;
  -webkit-line-clamp:2;
  -webkit-box-orient:vertical;
  overflow:hidden;
}
@media only screen and (max-width:540px){
  ul.message_view .message_view_photo{
    width:3.125rem;
    margin:0 0.3125rem 0.125rem 0;
  }
  [dir="rtl"] ul.message_view .message_view_photo{
    margin:0 0 0.125rem 0.3125rem;
  }
  ul.message_view .message_view_photo img {
    height:2.1875rem;
    width:2.1875rem;
  }
  ul.message_view .message_view_from{
    text-align:left;
  }
  ul.message_view .message_view_info{
    clear:both;
  }
  ul.message_view .message_quick_entry .message_view_leftwrapper{
    display:none;
  }
  ul.message_view .message_attachment{
    flex-direction:column;
  }
  ul.message_view .message_attachment_photo{
    background-color: var(--theme-list-background-color-alt);
    text-align:center !important;
    margin-bottom:0.3125rem;
    width:100%;
  }
  ul.message_view .message_attachment_photo img{
    width:auto;
    max-width:100%;
  }
  ul.message_view .message_attachment_info{
    width:100%;
  }
}

/*ATTACHMENT OPTIONS*/
#messages_compose .activity_post_media_options,
#messages_form_reply .activity_post_media_options{
  padding:0;
  border-width:0;
  margin:0.9375rem 0 0;
}
#messages_compose .compose-menu,
#messages_form_reply .compose-menu{
  margin:0.9375rem 0;
  width:100%;
}
#messages_compose .compose-menu .compose-menu-head,
#messages_form_reply .compose-menu .compose-menu-head{
  border-radius:0.3125rem;
  background-color:var(--theme-list-background-color-alt);
  padding:0.625rem;
  display:block;
  font-weight:var(--theme-font-weight-bold);
  overflow:hidden;
}
#messages_compose .compose-menu .compose-menu-head a,
#messages_form_reply .compose-menu .compose-menu-head a{
  float:right;
  padding:0.25rem;
}
[dir="rtl"] #messages_compose .compose-menu .compose-menu-head a,
[dir="rtl"] #messages_form_reply .compose-menu .compose-menu-heada a{
  float:right;
}

#global_page_messages-messages-view .tool_i_link,
#global_page_messages-messages-compose .tool_i_link,
#global_page_messages-messages-view #compose-link-activator,
#global_page_messages-messages-compose #compose-link-activator {
  display:flex !important;
}

/*REPLY FORM*/
#messages_form_reply > div,
#messages_form_reply > div > div{
  float:none !important;
  padding:0;
  width:100%;
}
#messsages_form_reply #mceLayout {
  margin-bottom:0.1875rem;
}
#messages_form_reply .form-label{
  display:none;
}
#messages_form_reply #submit-element{
  overflow:visible;
  margin:0;
}
#messages_form_reply #body-element{
  min-width:100%;
  max-width:100%;
  width:100%;
}
#messages_form_reply .compose-container,
#messages_form_reply .compose-content{
  width:100%;
}
#messages_form_reply #submit-element{
  float:none;
  overflow:hidden;
}

/*Hide Facebook and X share*/
#messages_form_reply #compose-menu span.composer_facebook_toggle,
#messages_form_reply #compose-menu span.composer_twitter_toggle {
  display:none;
}

/*COMPOSE MESSAGE FORM*/
#messages_compose .selectize-control.multi {
  position:inherit;
}
#messages_compose #toValues-wrapper{
  display:none;
}
#messages_compose #submit-element{
  float:none;
  overflow:hidden;
}
#messages_compose .compose-content{
  width:100%;
	min-height:4em;
	display:none;
	border-width:0.0625rem;
	border-radius:0;
}
#messages_compose #compose-menu{
  margin-top:0.625rem;
}
#global_page_messages-messages-compose #global_content_simple{
  background-color:var(--theme-list-background-color);
  display:block;
}
#global_page_messages-messages-compose #global_content_simple .layout_messages_menu,
#global_page_messages-messages-compose #global_content_simple .headline,
#global_page_messages-messages-compose #global_content_simple #submit-label{
  display:none;
}
#global_page_messages-messages-compose #global_content_simple .form-label{
  width:auto;
}
#global_page_messages-messages-compose #global_content_simple .layout_core_content{
  margin:0;
}
/* MESSAGES COMPOSE POPUP */
.messages_compose_popup .global_form > div > div > h3 + div {
  padding-left:0;
  padding-right:0;
}
.messages_compose_popup  #buttons-wrapper > fieldset{
  margin:0.9375rem 0;
  display:flex;
  align-items:center;
  gap:0.625rem;
}
.messages_compose_popup  #buttons-wrapper > fieldset button{
 margin:0;
}
.messages_compose_popup  #buttons-wrapper #cancel-label {
  display:none;
}
#global_content_simple .messages_compose_popup .form-element{
 max-width:100%;
 min-width:100%;
}
/*MESSAGES HOME WIDGET*/
.bg_item_photo_message:before{
	content:"\f27a";
}
.recent_messages .body{
  margin-bottom:0;
  margin-top:0.25rem;
	display:block;
  white-space:nowrap;
  overflow:hidden;
  text-overflow:ellipsis;
}
/* NOTIFICATION TYPE ICONS */
.icon_message:before,
.notification_type_message_new:before{
	font-family: uicons-regular-rounded !important;
	font-weight:400 !important;
	content:"\e785";
}