<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
return array(
  array(
    'title' => 'Recent Messages',
    'description' => 'Displays a list of the signed in user\'s recent messages.',
    'category' => 'Messages',
    'type' => 'widget',
    'name' => 'messages.home-messages',
    'isPaginated' => true,
    'defaultParams' => array(
      'title' => 'Recent Messages',
    ),
    'requirements' => array(
      'viewer',
      'no-subject',
    ),
  ),
  
  array(
    'title' => 'Messages Menu',
    'description' => 'Displays a menu in messages inbox, output, and compose pages.',
    'category' => 'Messages',
    'type' => 'widget',
    'name' => 'messages.menu',
    'requirements' => array(
      'no-subject',
    ),
  ),
) ?>
