<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<div class='clear'>

  <?php
    echo $this->navigation()
      ->menu()
      ->setContainer($this->navigation)
      ->setUlClass('admin_levels_tabs')
      ->render()
  ?>

  <div class='settings'>
    <?php echo $this->form->render($this) ?>
  </div>

</div>
